==> abtransfers_0.0.3.0.orig.tar.bz2: abtransfers-0.0.3.0/src/widgets/debugdialogwidget.h <==
/******************************************************************************
 * Copyright (C) 2011 Patrick Wacker
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307, USA.
 ******************************************************************************
 * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
 ******************************************************************************
 * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.3.0/src/widgets/debugdialogwidget.h $
 * $Author: Patrick Wacker $
 * $Date: 2012-04-07 13:47:16 +0200 (Sat, 07 Apr 2012) $
 * $Rev: 203 $
 *
 * description:
 *
 *
 * changes not documented here, see svn
 *
 ******************************************************************************/

#ifndef DEBUGDIALOGWIDGET_H
#define DEBUGDIALOGWIDGET_H

#include <QDialog>

namespace Ui {
	class DebugDialogWidget;
}

class DebugDialogWidget : public QDialog {
	Q_OBJECT
public:
	DebugDialogWidget(QWidget *parent = 0);
	~DebugDialogWidget();

protected:
	void changeEvent(QEvent *e);

private:
	Ui::DebugDialogWidget *ui;

public slots:
	void appendMsg(const QString &msg);

private slots:
	void on_pushButton_save_clicked();
};

#endif // DEBUGDIALOGWIDGET_H

==> abtransfers_0.0.4.1.orig.tar.bz2: abtransfers-0.0.4.1/src/widgets/debugdialogwidget.h <==
/******************************************************************************
 * Copyright (C) 2011 Patrick Wacker
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307, USA.
 ******************************************************************************
 * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
 ******************************************************************************
 * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/debugdialogwidget.h $
 * $Author: Patrick Wacker $
 * $Date: 2012-07-12 20:51:34 +0200 (Thu, 12 Jul 2012) $
 * $Rev: 298 $
 *
 * description:
 *
 *
 * changes not documented here, see svn
 *
 ******************************************************************************/

#ifndef DEBUGDIALOGWIDGET_H
#define DEBUGDIALOGWIDGET_H

#include <QDialog>

namespace Ui {
	class DebugDialogWidget;
}

/** \brief Widget um alle Meldungen die per qDebug() oder qWarning() ausgegeben
 *         werden an zu zeigen.
 *
 * Dieses Widget dient der Anzeige der Meldungen die normalerweise nur auf der
 * Konsole ausgegeben werden.
 * Über einen in main() gesetzen MsgHandler werden diese Ausgaben zusätzlich
 * an dieses Widget geleitet und können dann auch zur Laufzeit angezeigt werden.
 *
 */

class DebugDialogWidget : public QDialog {
	Q_OBJECT
public:
	DebugDialogWidget(QWidget *parent = 0);
	~DebugDialogWidget();

protected:
	void changeEvent(QEvent *e);

private:
	Ui::DebugDialogWidget *ui;

public slots:
	void appendMsg(const QString &msg);

private slots:
	void on_pushButton_save_clicked();
};

#endif // DEBUGDIALOGWIDGET_H
